@@ -48,6 +48,7 @@ MuonMainWindow::MuonMainWindow()
     , m_backend(0)
     , m_powerInhibitor(0)
     , m_canExit(false)
+    , m_isReloading(false)
     , m_actionsDisabled(false)
 {
 }
@@ -220,6 +221,9 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
     QString text;
     QString title;
 
+    if (m_isReloading)
+        return;
+
     switch (code) {
     case QApt::InitError: {
         text = i18nc("@label",
